@@ -4,15 +4,13 @@
 ## Shawn Nock, 2014
 
 import argparse
-import datetime
 import json
-import re
 import os
 import sys
 import time
 
 from qldemo import QLDemo, gametype_to_string
-from qldemo.data import GameState
+from qldemo.data import GameState, Snapshot
 from qldemo.constants import userinfo_map, GT_TEAM, TEAM_STRING_MAP
 
 ## Configuration ##
@@ -25,16 +23,6 @@ playerinfo_override = {'n': 'name',    ## The userInfo_t summary in
                        'l': 'losses',
                        't': 'team'}
 
-### How should we extract and format a timestamp from the filename
-timestamp_re = re.compile('([0-9]{4})_([0-9]{2})_([0-9]{2})-([0-9]{2})_([0-9]{2})_([0-9]{2})')
-def timestamp(filename):
-    hit = timestamp_re.search(filename)
-    if not hit:
-        return time.ctime(os.path.getctime(filename))
-    return datetime.datetime.strptime(
-        hit.group(0), 
-        "%Y_%m_%d-%H_%M_%S").ctime()
-
 ### END Configuration
 
 def main():
@@ -45,31 +33,46 @@ def main():
     args = parser.parse_args()
 
     d = QLDemo(args.file)
-    list(d) # parse all packets
+    list(d)
 
     ## Munge playerInfo to conform to ColonelPanic's Needs
     players=[]
-    for clientNum, player in d.gamestate.players.iteritems():
-        for key, value in player.iteritems():
-            new_name=dict(userinfo_map.items()+playerinfo_override.items()).get(key, None)
+    for clientNum, player in d.gamestate.players.items():
+        for key, value in player.items():
+            new_name=playerinfo_override.get(key, None)
             if new_name:
                 player[new_name]=player[key]
                 del(player[key])
-        player['score']=None
+        player['score']=d.gamestate.scores[clientNum]
         # If it's a game where teams make sense, translate the teamId into a team name
         if int(d.gamestate.config['server_info']['g_gametype']) >= GT_TEAM:
             player['team']=TEAM_STRING_MAP[player['team']]
         players.append(player)
+
+    # Calculate demo duration
+    ## FIXME - I think serverTime is in msec, but it is a guess based
+    ## on a skim of the Q3A source. It'd be nice to verify
+    first_snap=None
+    last_snap=None
+    for i in d.packets:
+        if i.__class__ is Snapshot:
+            first_snap=i
+            break
+    for i in range(-1,-5,-1):
+        if d.packets[i].__class__ is Snapshot:
+            last_snap=d.packets[i]
+            break
+    duration = (last_snap.serverTime - first_snap.serverTime) / 1000
     
-    output = {'filename': args.file,
-              'url': ''.join([URL_PREFIX, args.file.split(os.sep)[-1]]),
+    output = {'filename': args.file.split(os.sep)[-1],
               'gametype': gametype_to_string(
                   d.gamestate.config['server_info']['g_gametype']),
               'players': d.gamestate.players,
               'size': os.stat(args.file).st_size,
-              'pov': d.gamestate.players[d.gamestate.clientNum]['name'],
-              'timestamp': timestamp(args.file),
-              'duration': None,
+              'pov': d.gamestate.clientNum,
+              'timestamp': time.ctime(float(d.gamestate.config['server_info']['g_levelStartTime'])),
+              'mapname': d.gamestate.config['server_info']['mapname'],
+              'duration': duration,
               'victor': None}
     
     ## Add team list, if it's a team type of game
@@ -82,7 +85,8 @@ def main():
     json.dump(output, 
               sys.stdout, 
               ensure_ascii=False,
-              indent=2)
+              indent=2,
+              sort_keys=True)
     return 0
 
 if __name__ == '__main__':
